@@ -373,9 +373,9 @@ class BatchProcessor:
         status = {
             "status": self.db.get_status_counts(),
             "last": self.db.get_last_jobs(limit=20),
-            "last_failed": self.db.get_last_jobs(limit=20, status="failed"),
-            "last_pending": self.db.get_last_jobs(limit=20, status="pending"),
-            "last_in_progress": self.db.get_last_jobs(limit=20, status="in_progress"),
+            "last_failed": self.db.get_last_jobs(limit=20, status=["failed"]),
+            "last_pending": self.db.get_last_jobs(limit=20, status=["pending"]),
+            "last_in_progress": self.db.get_last_jobs(limit=20, status=["in_progress"]),
             "counts": self.get_job_counts()}
         # fmt: on
         return status
