@@ -107,7 +107,9 @@ begin
     return left_millis;
 end
 $$ language plpgsql;
-""",[])
+""",
+            [],
+        )
 
     # Look at faster batch imports with
     # from psycopg2.extras import execute_values
@@ -235,6 +237,19 @@ $$ language plpgsql;
                 {"id": (id,), "status": (status,), "error": (error,), "result": (result,), "updated_at": (updated_at,)},
             )
 
+    # Simplified version of bump_batch_item where status is updated, no questions asked
+    def bump_batch_item_status(self, id, status):
+        self.dbc.query_none(
+            """
+                update batch_log
+                    set status=%(status)s,
+                    updated_at=now()
+                where id = %(id)s
+                ;
+                """,
+            {"id": (id,), "status": (status,)},
+        )
+
     # Update a batch item in the batch log, making sure to fail if the id and updated_at don't match, providing a guarantee of atomic operation
     def book_batch_item(self, from_status=PENDING, to_status=IN_PROGRESS):
         return self.dbc.query_one(
@@ -281,7 +296,6 @@ $$ language plpgsql;
             {"from_status": (from_status,), "to_status": (to_status,)},
         )
 
-
     # Delete batch items with given status and update_at longer than given time
     def delete_batch_items_with_status_older_than(self, status, updated_at):
         self.dbc.query_none(
@@ -303,7 +317,6 @@ $$ language plpgsql;
                 """
         )
 
-    
     # Get batch items from batch log fitting the optional filter
     def get_batch_items(self, id=None, priority=None, type=None, status=None, throttle_key=None, source=None, limit=1):
         return self.dbc.query_many(
@@ -401,7 +414,7 @@ $$ language plpgsql;
                 ;
                 """
         )
-    
+
     # Get count of ready pending batch items taking into acount throttling
     def get_throttled_pending_count(self):
         return self.dbc.query_many(
@@ -413,9 +426,7 @@ $$ language plpgsql;
                 ;
                 """
         )
-    
-    
-    
+
     # Get ready pending batch items taking into acount throttling
     def get_throttled_pending(self):
         return self.dbc.query_many(
@@ -428,7 +439,7 @@ $$ language plpgsql;
                 ;
                 """
         )
-        
+
     def get_job_counts(self):
         return self.dbc.query_many(
             """
